==> react-native-cometchat-calling-component-3.0.3.tgz: package/CometChatCallingComponent.js <==
import React, { Component } from 'react';
import App from './App';
import reducers from './reducers/reducer';
import { createStore,combineReducers } from 'redux';
import { Provider } from 'react-redux';
import {NativeEventEmitter} from 'react-native';
import JitsiManager from './lib/JitsiManager';
import Logger from './lib/Logger';
import AudioMode from './AudioMode'
import CallingComponent from 'react-native-cometchat-calling-component/CallingComponent';
import RTCManager from 'react-native-cometchat-calling-component/lib/RTCManager';


var eventEmitter = new NativeEventEmitter(AudioMode);

export default class CometChatCallingComponent extends Component{
    constructor(props){
        super(props);
        const rootReducer = combineReducers(reducers);
        this.storeObj = createStore(rootReducer);
        JitsiManager.setCallObject(this.props.RTCUser,this.props.RTCReceiver,this.props.RTCInitiator,this.props.isInitiator);
        JitsiManager.setRegion(this.props.REGION);
        JitsiManager.setAudioOnly(this.props.isAudioOnly);
    }
    
    componentDidMount() {
        this.eventListener = new NativeEventEmitter(AudioMode);
        this.eventListener.addListener('CallEvent',(type) =>{
            Logger.log("CallEvent received : ",type)

            if(type.type == "EndCall"){
                this.props.onEndCall();
            }

            if(type.type == "EndCallButtonPressed"){
                this.props.onCallEndButtonPressed();
            }
        });
    }

    render(){
        return(
            <Provider store={this.storeObj}>
                <App 
                    sessionid={this.props.sessionId}
                    enableDefaultLayout = {this.props.enableDefaultLayout}
                    hideAudioMuteButton = {this.props.hideAudioMuteButton}
                    hideEndCallButton = {this.props.hideEndCallButton}
                    hidePauseVideoButton = {this.props.hidePauseVideoButton}
                    hideVideoSwitchButton = {this.props.hideVideoSwitchButton}
                    hideAudioModeButton = {this.props.hideAudioModeButton}
                    isAudioOnly = {this.props.isAudioOnly}
                    isConference = {this.props.isConference}
                    uid = {this.props.uid}
                    RTCUser = {this.props.RTCUser}
                    isSingleMode = {this.props.isSingleMode}
                    mode = {this.props.mode}
                    REGION = {this.props.REGION}
                    domain = {this.props.domain}
                />
            </Provider>
        );
    }
}  
CometChatCallingComponent.endCallSession=()=>{
    eventEmitter.emit('CallEvent', { type: 'NativeEndCall' });
    RTCManager.endCall();
}

CometChatCallingComponent.switchCameraSource=()=>{
    RTCManager.switchCamera();
}
CometChatCallingComponent.muteAudio=()=>{
    RTCManager.muteAudio();
}
CometChatCallingComponent.unMuteAudio=()=>{
    RTCManager.unMuteAudio();
}
CometChatCallingComponent.pauseVideo=()=>{
    RTCManager.pauseVideo()
}
CometChatCallingComponent.unPauseVideo=()=>{
    RTCManager.unPauseVideo()
}
CometChatCallingComponent.setAudioModeToSpeaker=()=>{
    //JitsiManager.setAudioModeSpeaker();
}
CometChatCallingComponent.setAudioModeToEarPiece=()=>{
    //JitsiManager.setAudioModeEarpiece();
}

==> react-native-cometchat-calling-component-3.0.6.tgz: package/CometChatCallingComponent.js <==
import React, { Component } from 'react';
import App from './App';
import {NativeEventEmitter} from 'react-native';
import JitsiManager from './lib/JitsiManager';
import Logger from './lib/Logger';
import AudioMode from './AudioMode'

import RTCManager from './lib/RTCManager';


var eventEmitter = new NativeEventEmitter(AudioMode);

export default class CometChatCallingComponent extends Component{
    constructor(props){
        super(props);
        JitsiManager.setCallObject(this.props.RTCUser,this.props.RTCReceiver,this.props.RTCInitiator,this.props.isInitiator);
        JitsiManager.setRegion(this.props.REGION);
        JitsiManager.setAudioOnly(this.props.isAudioOnly);
    }
    
    componentDidMount() {
        this.eventListener = new NativeEventEmitter(AudioMode);
        this.eventListener.addListener('CallEvent',(type) =>{
            Logger.log("CallEvent received : ",type)

            if(type.type == "EndCall"){
                this.props.onEndCall();
            }

            if(type.type == "EndCallButtonPressed"){
                this.props.onCallEndButtonPressed();
            }
        });
    }

    render(){
        return(
                <App 
                    sessionid={this.props.sessionId}
                    enableDefaultLayout = {this.props.enableDefaultLayout}
                    hideAudioMuteButton = {this.props.hideAudioMuteButton}
                    hideEndCallButton = {this.props.hideEndCallButton}
                    hidePauseVideoButton = {this.props.hidePauseVideoButton}
                    hideVideoSwitchButton = {this.props.hideVideoSwitchButton}
                    hideAudioModeButton = {this.props.hideAudioModeButton}
                    isAudioOnly = {this.props.isAudioOnly}
                    isConference = {this.props.isConference}
                    uid = {this.props.uid}
                    RTCUser = {this.props.RTCUser}
                    isSingleMode = {this.props.isSingleMode}
                    mode = {this.props.mode}
                    REGION = {this.props.REGION}
                    domain = {this.props.domain}
                />
        );
    }
}  
CometChatCallingComponent.endCallSession=()=>{
    eventEmitter.emit('CallEvent', { type: 'NativeEndCall' });
    RTCManager.endCall();
}

CometChatCallingComponent.switchCameraSource=()=>{
    RTCManager.switchCamera();
}
CometChatCallingComponent.muteAudio=()=>{
    RTCManager.muteAudio();
}
CometChatCallingComponent.unMuteAudio=()=>{
    RTCManager.unMuteAudio();
}
CometChatCallingComponent.pauseVideo=()=>{
    RTCManager.pauseVideo()
}
CometChatCallingComponent.unPauseVideo=()=>{
    RTCManager.unPauseVideo()
}
CometChatCallingComponent.setAudioModeToSpeaker=()=>{
    //JitsiManager.setAudioModeSpeaker();
}
CometChatCallingComponent.setAudioModeToEarPiece=()=>{
    //JitsiManager.setAudioModeEarpiece();
}
